/*
 * ZoneMinder Base Stylesheet, $Date$, $Revision$
 * Copyright (C) 2001-2008 Philip Coombes
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */ 

/*
 * Primary look and feel styles
 */

body {
    color: #dddddd;
    background-color: #222222;
}

h1 {
    color: #10a4e8;
}

h2 {
    color: #10a4e8;
}

h3 {
    color: #117AAd;
}

h4 {
    color: #117AAd;
}

p {
    color: #dddddd;
}

th {
    color: #117AAd;
}

img.normal {
    border: #cccccc solid 1px;
}

hr {
    color: #8f8fc2;
    background-color: #8f8fc2;
}

ul.tabList li {
    color: #8f8fc2;
    border: #8f8fc2 solid 1px;
    background: #444444;
}

ul.tabList li:hover {
    background-color: #dddddd;
}

ul.tabList li.active {
    background-color: #222222;
    border-bottom: #8f8fc2 dotted 1px;
}

/*
 * Major league table for multiple inputs or presentation
 */

#content table.major tr.highlight {
    color: #eeeeee;
    background-color: #000000;
}

#content table.major th, #content table.major td {
    border-bottom: 2px solid #8f8fc2;
}

#content table > tbody > tr:hover
{
    background-color: #333333;
}

.overlay {
    background-color: #222222;
}

.overlay .overlayHeader {
    color: #eeeeee;
    background-color: #070707;
}

.overlay fieldset {
    background-color: #222222;
}

.validation-advice {
    padding: 4px;
    color: #dc143c;
}

fieldset {
    border: 1px solid #dddddd;
}

/*
 * Behavior classes
 */
.alarm, .errorText {
    color: #dc143c;
}

.alert, .warnText {
    color: #ff8c00;
}

.ok, .infoText {
    color: #77a328;
}

.fakelink {
    color: #8f8fc2;
    cursor: pointer;
}

.fakelink:hover {
    color: #336699;
    text-decoration: none;
}

.table-tr-odd {
    background-color: #070707;
}

#header {
    border-bottom: 1px solid #000000;
}

input {
  background-color: rgb(68,68,68);
  color: #999;
}
/* PP - make it easy to identify disabled buttons */

button:disabled,
input[disabled],
input[type=button]:disabled,
input[type=submit]:disabled,
.btn-primary:disabled {
  color: #888888;
  background-color: #666666;
  border-color: #666666;
}

.navbar {
  margin-bottom: 0 !important;
  border-radius: 0;
  color: #03A9F4 !important;
}

.sidebar {
  border-right: 1px solid #eeeeee;
  background-color: #222222;
}

.table-striped > tbody > tr:nth-of-type(2n+1) {
  background-color: #333333;
}

.table-hover>tbody>tr:hover {
  background-color: #444444;
}

.nav-pills>li.active>a, .nav-pills>li.active>a:focus, .nav-pills>li.active>a:hover {
  color: #ffa801;
  background-color: #333333;
}

.nav>li>a:focus, .nav>li>a:hover {
  background-color: #444444;
}

/* Override chosen for dark theme */
.chosen-single,
.chosen-container,
.chosen-container-multi,
.chosen-results,
.chosen-search,
.chosen-drop,
.chosen-choices,
li.search-choice {
    font-size: inherit !important;
    background: -webkit-gradient(linear,left top,left bottom,color-stop(20%,#555),color-stop(50%,#464646),color-stop(52%,#444),to(#545454)) !important;
    background: linear-gradient(#555 20%,#464646 50%,#444 52%,#545454 100%) !important;
    background-color: #444444 !important;
    color: #eee !important;
    -webkit-box-shadow: none !important;
    background-image: none !important;
}
/* end chosen override */
