#content {
    position: relative;
    text-align: center;
    border: 1px solid #666666;
    margin: 0 auto;
}

#header {
    display: flex;
    justify-content: space-between;
}

#header h2, #header a {
    line-height: 1.1;
    margin:5px 0 0 0;
}

#header #info, #header #headerButtons {
    display: flex;
    flex-direction: column;
}

#header #headerButtons {
    align-items: flex-end;
}

#title {
    position: relative;
    margin: 0 auto;
    color: #016A9D;
    height: 30px;
    font-size: 13px;
    font-weight: bold;
    line-height: 20px;
}

#topPanel {
    position: relative;
    height: 220px;
    margin: 4px auto 6px;
}

#topPanel #imagePanel 
{
    width: 50%;
    float: left;
    text-align: right;
}

#topPanel #image {
    float: right;
    margin: 0 auto;
    width: 90%;
    text-align: right;
    margin-right: 2px;
    background-color: #222222;
    border: 1px solid #cccccc;
}

#topPanel #image img {
    float: left;
    top: 0px;
    background-color: #222222;
    width: 100%;
}

#topPanel #dataPanel {
    width: 45%;
    float: left;
    text-align: left;
    margin-left: 2px;
}

#topPanel #textPanel {
    text-align: left;
    width: 100%;
    margin: 0 auto;
    color: #dddddd;
    font-size: 11px;
    font-weight: bold;
    line-height: 14px;
    background-color: #222222;
    border: 1px solid #cccccc;
    padding: 2px;
}

#topPanel #navPanel {
    width: 100%;
    height: 70px;
    margin: 4px auto;
}

#topPanel #navPanel input {
    background-color: #111111;
    border: 1px solid #cccccc;
    padding: 5px;
}

#chartPanel {
    position: relative;
    margin: 0 auto;
}

#chartPanel #chart {
    position: relative;
    border: 1px solid black;
    margin: 0 auto;
    z-index: 0;
}

#chartPanel #activity {
    position: absolute;
    text-align: center;
    left: 0px;
    border-bottom: 1px solid #cccccc;
}

#chartPanel #activity div.activity {
    position: absolute;
    bottom: 0px;
    z-index: 3;
    width: 1px;
}

#chartPanel .events {
    position: absolute;
    text-align: center;
    left: 0px;
    background-color: #000000;
    border-bottom: 1px solid #cccccc;
}

#chartPanel .event {
    position: absolute;
    bottom: 0px;
    z-index: 3;
}

#chartLabels {
    margin: 25px auto 0;
    text-align: center;
}

#range {
    width: 30%;
    margin: 0 auto;
    color: #016A9D;
    font-size: 11px;
    font-weight: bold;
    line-height: 20px;
}

#key {
    float: right;
    margin-top: -4px;
    text-align: right;
}

span.keyEntry {
}

img.keyBox {
    position: relative;
    border: 1px solid black;
    width: 16px;
    height: 16px;
    top: 4px;
    margin-left: 4px;
}

div.majGridX {
    position: absolute;
    z-index: 1;
    top: 0px;
    width: 1px;
    border-left: dotted 1px #cccccc;
}

div.majTickX {
    position: absolute;
    bottom: -7px;
    width: 1px;
    height: 7px;
    border-left: solid 1px black;
}

div.majLabelX {
    position: absolute;
    text-align: center;
    bottom: -20px;
    width: 50px;
    font-size: 9px;
    font-weight: normal;
}

div.majGridY {
    position: absolute;
    z-index: 1;
    left: 0px;
    height: 1px;
    border-top: dotted 1px #cccccc;
}

div.majTickY {
    position: absolute;
    left: -7px;
    height: 1px;
    width: 7px;
    border-top: solid 1px black;
}

div.majLabelY {
    position: absolute;
    text-align: right;
    left: -30px;
    width: 20px;
    font-size: 9px;
    font-weight: normal;
}

div.zoom {
    position: absolute;
    z-index: 2;
    bottom: 0px;
}

