
package WSNotification::Typemaps::WSBaseNotificationSender;
use strict;
use warnings;

our $typemap_1 = {
               'InvalidMessageContentExpressionFault/Description' => 'WSNotification::Types::BaseFaultType::_Description',
               'Subscribe/InitialTerminationTime' => 'WSNotification::Types::AbsoluteOrRelativeTimeType',
               'InvalidTopicExpressionFault/Originator' => 'WSNotification::Types::EndpointReferenceType',
               'NotifyMessageNotSupportedFault/Description' => 'WSNotification::Types::BaseFaultType::_Description',
               'SubscribeCreationFailedFault' => 'WSNotification::Elements::SubscribeCreationFailedFault',
               'UnsupportedPolicyRequestFault' => 'WSNotification::Elements::UnsupportedPolicyRequestFault',
               'UnrecognizedPolicyRequestFault/Timestamp' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'Subscribe/Filter/MessageContent' => 'WSNotification::Types::QueryExpressionType',
               'InvalidMessageContentExpressionFault/Originator/Metadata' => 'WSNotification::Types::MetadataType',
               'UnacceptableInitialTerminationTimeFault/Originator/Address' => 'WSNotification::Types::AttributedURIType',
               'NoCurrentMessageOnTopicFault/Description' => 'WSNotification::Types::BaseFaultType::_Description',
               'UnacceptableInitialTerminationTimeFault/Originator/ReferenceParameters' => 'WSNotification::Types::ReferenceParametersType',
               'NotifyMessageNotSupportedFault/Originator/Address' => 'WSNotification::Types::AttributedURIType',
               'UnacceptableInitialTerminationTimeFault' => 'WSNotification::Elements::UnacceptableInitialTerminationTimeFault',
               'InvalidProducerPropertiesExpressionFault/Originator/Metadata' => 'WSNotification::Types::MetadataType',
               'SubscribeCreationFailedFault/Originator' => 'WSNotification::Types::EndpointReferenceType',
               'NotifyMessageNotSupportedFault/ErrorCode' => 'WSNotification::Types::BaseFaultType::_ErrorCode',
               'NotifyMessageNotSupportedFault/FaultCause' => 'WSNotification::Types::BaseFaultType::_FaultCause',
               'TopicNotSupportedFault/Timestamp' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'RenewResponse' => 'WSNotification::Elements::RenewResponse',
               'InvalidMessageContentExpressionFault/FaultCause' => 'WSNotification::Types::BaseFaultType::_FaultCause',
               'UnableToDestroySubscriptionFault/Originator/ReferenceParameters' => 'WSNotification::Types::ReferenceParametersType',
               'TopicExpressionDialectUnknownFault/Description' => 'WSNotification::Types::BaseFaultType::_Description',
               'UnacceptableTerminationTimeFault/Originator/Address' => 'WSNotification::Types::AttributedURIType',
               'UnacceptableTerminationTimeFault/FaultCause' => 'WSNotification::Types::BaseFaultType::_FaultCause',
               'InvalidFilterFault/Originator/Metadata' => 'WSNotification::Types::MetadataType',
               'UnableToDestroySubscriptionFault/Originator/Address' => 'WSNotification::Types::AttributedURIType',
               'UnrecognizedPolicyRequestFault/Originator/ReferenceParameters' => 'WSNotification::Types::ReferenceParametersType',
               'UnrecognizedPolicyRequestFault/UnrecognizedPolicy' => 'SOAP::WSDL::XSD::Typelib::Builtin::QName',
               'InvalidProducerPropertiesExpressionFault/Description' => 'WSNotification::Types::BaseFaultType::_Description',
               'Fault/detail' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Renew' => 'WSNotification::Elements::Renew',
               'UnsupportedPolicyRequestFault/Timestamp' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'TopicExpressionDialectUnknownFault' => 'WSNotification::Elements::TopicExpressionDialectUnknownFault',
               'UnacceptableInitialTerminationTimeFault/ErrorCode' => 'WSNotification::Types::BaseFaultType::_ErrorCode',
               'InvalidTopicExpressionFault/Originator/Metadata' => 'WSNotification::Types::MetadataType',
               'MultipleTopicsSpecifiedFault/Description' => 'WSNotification::Types::BaseFaultType::_Description',
               'UnrecognizedPolicyRequestFault/ErrorCode' => 'WSNotification::Types::BaseFaultType::_ErrorCode',
               'InvalidMessageContentExpressionFault/Timestamp' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'Subscribe/ConsumerReference/Address' => 'WSNotification::Types::AttributedURIType',
               'TopicExpressionDialectUnknownFault/Timestamp' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'UnacceptableTerminationTimeFault/Description' => 'WSNotification::Types::BaseFaultType::_Description',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'UnsupportedPolicyRequestFault/UnsupportedPolicy' => 'SOAP::WSDL::XSD::Typelib::Builtin::QName',
               'Subscribe/ConsumerReference/ReferenceParameters' => 'WSNotification::Types::ReferenceParametersType',
               'MultipleTopicsSpecifiedFault/Originator/ReferenceParameters' => 'WSNotification::Types::ReferenceParametersType',
               'TopicExpressionDialectUnknownFault/Originator' => 'WSNotification::Types::EndpointReferenceType',
               'UnrecognizedPolicyRequestFault/Description' => 'WSNotification::Types::BaseFaultType::_Description',
               'TopicNotSupportedFault/Originator/Metadata' => 'WSNotification::Types::MetadataType',
               'InvalidProducerPropertiesExpressionFault/Timestamp' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'Unsubscribe' => 'WSNotification::Elements::Unsubscribe',
               'NoCurrentMessageOnTopicFault/ErrorCode' => 'WSNotification::Types::BaseFaultType::_ErrorCode',
               'TopicNotSupportedFault/Originator/ReferenceParameters' => 'WSNotification::Types::ReferenceParametersType',
               'TopicNotSupportedFault/FaultCause' => 'WSNotification::Types::BaseFaultType::_FaultCause',
               'MultipleTopicsSpecifiedFault/Originator/Address' => 'WSNotification::Types::AttributedURIType',
               'UnableToDestroySubscriptionFault/Originator' => 'WSNotification::Types::EndpointReferenceType',
               'UnacceptableInitialTerminationTimeFault/Description' => 'WSNotification::Types::BaseFaultType::_Description',
               'InvalidTopicExpressionFault/Originator/Address' => 'WSNotification::Types::AttributedURIType',
               'UnacceptableTerminationTimeFault/Originator' => 'WSNotification::Types::EndpointReferenceType',
               'RenewResponse/CurrentTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'MultipleTopicsSpecifiedFault/Timestamp' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'InvalidProducerPropertiesExpressionFault/Originator/ReferenceParameters' => 'WSNotification::Types::ReferenceParametersType',
               'UnsupportedPolicyRequestFault/Originator/Address' => 'WSNotification::Types::AttributedURIType',
               'NoCurrentMessageOnTopicFault/FaultCause' => 'WSNotification::Types::BaseFaultType::_FaultCause',
               'SubscribeCreationFailedFault/Timestamp' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'UnrecognizedPolicyRequestFault/FaultCause' => 'WSNotification::Types::BaseFaultType::_FaultCause',
               'Subscribe/SubscriptionPolicy' => 'WSNotification::Elements::Subscribe::_SubscriptionPolicy',
               'InvalidFilterFault/Timestamp' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'InvalidProducerPropertiesExpressionFault/Originator' => 'WSNotification::Types::EndpointReferenceType',
               'NoCurrentMessageOnTopicFault/Originator/Address' => 'WSNotification::Types::AttributedURIType',
               'TopicNotSupportedFault/Description' => 'WSNotification::Types::BaseFaultType::_Description',
               'UnrecognizedPolicyRequestFault/Originator/Address' => 'WSNotification::Types::AttributedURIType',
               'NoCurrentMessageOnTopicFault/Originator/Metadata' => 'WSNotification::Types::MetadataType',
               'InvalidProducerPropertiesExpressionFault/ErrorCode' => 'WSNotification::Types::BaseFaultType::_ErrorCode',
               'Renew/TerminationTime' => 'WSNotification::Types::AbsoluteOrRelativeTimeType',
               'UnsupportedPolicyRequestFault/ErrorCode' => 'WSNotification::Types::BaseFaultType::_ErrorCode',
               'InvalidTopicExpressionFault/ErrorCode' => 'WSNotification::Types::BaseFaultType::_ErrorCode',
               'TopicNotSupportedFault/ErrorCode' => 'WSNotification::Types::BaseFaultType::_ErrorCode',
               'UnacceptableTerminationTimeFault/Timestamp' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'UnrecognizedPolicyRequestFault' => 'WSNotification::Elements::UnrecognizedPolicyRequestFault',
               'UnacceptableTerminationTimeFault/MinimumTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'InvalidTopicExpressionFault/FaultCause' => 'WSNotification::Types::BaseFaultType::_FaultCause',
               'SubscribeCreationFailedFault/Originator/ReferenceParameters' => 'WSNotification::Types::ReferenceParametersType',
               'UnsupportedPolicyRequestFault/Description' => 'WSNotification::Types::BaseFaultType::_Description',
               'RenewResponse/TerminationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'InvalidTopicExpressionFault/Description' => 'WSNotification::Types::BaseFaultType::_Description',
               'TopicExpressionDialectUnknownFault/ErrorCode' => 'WSNotification::Types::BaseFaultType::_ErrorCode',
               'UnacceptableInitialTerminationTimeFault/Originator/Metadata' => 'WSNotification::Types::MetadataType',
               'InvalidTopicExpressionFault/Timestamp' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'SubscribeResponse/SubscriptionReference/ReferenceParameters' => 'WSNotification::Types::ReferenceParametersType',
               'InvalidMessageContentExpressionFault/Originator/Address' => 'WSNotification::Types::AttributedURIType',
               'Subscribe/ConsumerReference' => 'WSNotification::Types::EndpointReferenceType',
               'UnableToDestroySubscriptionFault/FaultCause' => 'WSNotification::Types::BaseFaultType::_FaultCause',
               'GetCurrentMessage' => 'WSNotification::Elements::GetCurrentMessage',
               'TopicExpressionDialectUnknownFault/Originator/Address' => 'WSNotification::Types::AttributedURIType',
               'SubscribeCreationFailedFault/Description' => 'WSNotification::Types::BaseFaultType::_Description',
               'NoCurrentMessageOnTopicFault/Originator/ReferenceParameters' => 'WSNotification::Types::ReferenceParametersType',
               'UnrecognizedPolicyRequestFault/Originator' => 'WSNotification::Types::EndpointReferenceType',
               'InvalidFilterFault/Originator/Address' => 'WSNotification::Types::AttributedURIType',
               'SubscribeCreationFailedFault/Originator/Address' => 'WSNotification::Types::AttributedURIType',
               'InvalidFilterFault/ErrorCode' => 'WSNotification::Types::BaseFaultType::_ErrorCode',
               'TopicExpressionDialectUnknownFault/Originator/Metadata' => 'WSNotification::Types::MetadataType',
               'InvalidFilterFault/FaultCause' => 'WSNotification::Types::BaseFaultType::_FaultCause',
               'UnacceptableInitialTerminationTimeFault/MaximumTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'NotifyMessageNotSupportedFault/Originator' => 'WSNotification::Types::EndpointReferenceType',
               'SubscribeResponse/SubscriptionReference/Address' => 'WSNotification::Types::AttributedURIType',
               'NoCurrentMessageOnTopicFault/Originator' => 'WSNotification::Types::EndpointReferenceType',
               'SubscribeCreationFailedFault/FaultCause' => 'WSNotification::Types::BaseFaultType::_FaultCause',
               'NotifyMessageNotSupportedFault/Originator/ReferenceParameters' => 'WSNotification::Types::ReferenceParametersType',
               'TopicNotSupportedFault/Originator/Address' => 'WSNotification::Types::AttributedURIType',
               'UnsupportedPolicyRequestFault/FaultCause' => 'WSNotification::Types::BaseFaultType::_FaultCause',
               'TopicExpressionDialectUnknownFault/Originator/ReferenceParameters' => 'WSNotification::Types::ReferenceParametersType',
               'UnableToDestroySubscriptionFault/Originator/Metadata' => 'WSNotification::Types::MetadataType',
               'SubscribeCreationFailedFault/Originator/Metadata' => 'WSNotification::Types::MetadataType',
               'TopicNotSupportedFault' => 'WSNotification::Elements::TopicNotSupportedFault',
               'InvalidMessageContentExpressionFault/Originator' => 'WSNotification::Types::EndpointReferenceType',
               'MultipleTopicsSpecifiedFault/FaultCause' => 'WSNotification::Types::BaseFaultType::_FaultCause',
               'InvalidFilterFault/Description' => 'WSNotification::Types::BaseFaultType::_Description',
               'MultipleTopicsSpecifiedFault/ErrorCode' => 'WSNotification::Types::BaseFaultType::_ErrorCode',
               'UnsubscribeResponse' => 'WSNotification::Elements::UnsubscribeResponse',
               'Subscribe' => 'WSNotification::Elements::Subscribe',
               'GetCurrentMessageResponse' => 'WSNotification::Elements::GetCurrentMessageResponse',
               'NotifyMessageNotSupportedFault/Timestamp' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'MultipleTopicsSpecifiedFault/Originator/Metadata' => 'WSNotification::Types::MetadataType',
               'NoCurrentMessageOnTopicFault/Timestamp' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'UnacceptableInitialTerminationTimeFault/Originator' => 'WSNotification::Types::EndpointReferenceType',
               'Subscribe/ConsumerReference/Metadata' => 'WSNotification::Types::MetadataType',
               'UnsupportedPolicyRequestFault/Originator/ReferenceParameters' => 'WSNotification::Types::ReferenceParametersType',
               'NotifyMessageNotSupportedFault' => 'WSNotification::Elements::NotifyMessageNotSupportedFault',
               'InvalidTopicExpressionFault' => 'WSNotification::Elements::InvalidTopicExpressionFault',
               'UnableToDestroySubscriptionFault/ErrorCode' => 'WSNotification::Types::BaseFaultType::_ErrorCode',
               'InvalidFilterFault' => 'WSNotification::Elements::InvalidFilterFault',
               'GetCurrentMessage/Topic' => 'WSNotification::Types::TopicExpressionType',
               'SubscribeResponse/SubscriptionReference/Metadata' => 'WSNotification::Types::MetadataType',
               'InvalidFilterFault/Originator/ReferenceParameters' => 'WSNotification::Types::ReferenceParametersType',
               'InvalidMessageContentExpressionFault/Originator/ReferenceParameters' => 'WSNotification::Types::ReferenceParametersType',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'Subscribe/Filter/TopicExpression' => 'WSNotification::Types::TopicExpressionType',
               'SubscribeResponse' => 'WSNotification::Elements::SubscribeResponse',
               'TopicExpressionDialectUnknownFault/FaultCause' => 'WSNotification::Types::BaseFaultType::_FaultCause',
               'InvalidMessageContentExpressionFault' => 'WSNotification::Elements::InvalidMessageContentExpressionFault',
               'NotifyMessageNotSupportedFault/Originator/Metadata' => 'WSNotification::Types::MetadataType',
               'UnrecognizedPolicyRequestFault/Originator/Metadata' => 'WSNotification::Types::MetadataType',
               'SubscribeCreationFailedFault/ErrorCode' => 'WSNotification::Types::BaseFaultType::_ErrorCode',
               'MultipleTopicsSpecifiedFault/Originator' => 'WSNotification::Types::EndpointReferenceType',
               'SubscribeResponse/SubscriptionReference' => 'WSNotification::Types::EndpointReferenceType',
               'UnsupportedPolicyRequestFault/Originator' => 'WSNotification::Types::EndpointReferenceType',
               'InvalidFilterFault/Originator' => 'WSNotification::Types::EndpointReferenceType',
               'NoCurrentMessageOnTopicFault' => 'WSNotification::Elements::NoCurrentMessageOnTopicFault',
               'InvalidMessageContentExpressionFault/ErrorCode' => 'WSNotification::Types::BaseFaultType::_ErrorCode',
               'UnsupportedPolicyRequestFault/Originator/Metadata' => 'WSNotification::Types::MetadataType',
               'UnacceptableTerminationTimeFault/ErrorCode' => 'WSNotification::Types::BaseFaultType::_ErrorCode',
               'UnableToDestroySubscriptionFault' => 'WSNotification::Elements::UnableToDestroySubscriptionFault',
               'UnacceptableTerminationTimeFault' => 'WSNotification::Elements::UnacceptableTerminationTimeFault',
               'Subscribe/Filter' => 'WSNotification::Types::FilterType',
               'UnacceptableTerminationTimeFault/Originator/Metadata' => 'WSNotification::Types::MetadataType',
               'InvalidTopicExpressionFault/Originator/ReferenceParameters' => 'WSNotification::Types::ReferenceParametersType',
               'UnacceptableInitialTerminationTimeFault/Timestamp' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'MultipleTopicsSpecifiedFault' => 'WSNotification::Elements::MultipleTopicsSpecifiedFault',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'TopicNotSupportedFault/Originator' => 'WSNotification::Types::EndpointReferenceType',
               'UnacceptableTerminationTimeFault/MaximumTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'InvalidProducerPropertiesExpressionFault/Originator/Address' => 'WSNotification::Types::AttributedURIType',
               'InvalidProducerPropertiesExpressionFault' => 'WSNotification::Elements::InvalidProducerPropertiesExpressionFault',
               'UnacceptableTerminationTimeFault/Originator/ReferenceParameters' => 'WSNotification::Types::ReferenceParametersType',
               'SubscribeResponse/CurrentTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'UnacceptableInitialTerminationTimeFault/MinimumTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'SubscribeResponse/TerminationTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
               'InvalidFilterFault/UnknownFilter' => 'SOAP::WSDL::XSD::Typelib::Builtin::QName',
               'UnableToDestroySubscriptionFault/Description' => 'WSNotification::Types::BaseFaultType::_Description',
               'UnacceptableInitialTerminationTimeFault/FaultCause' => 'WSNotification::Types::BaseFaultType::_FaultCause',
               'InvalidProducerPropertiesExpressionFault/FaultCause' => 'WSNotification::Types::BaseFaultType::_FaultCause',
               'UnableToDestroySubscriptionFault/Timestamp' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

WSNotification::Typemaps::WSBaseNotificationSender - typemap for WSBaseNotificationSender

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

