
package ONVIF::Media::Elements::GetVideoEncoderConfigurationOptionsResponse;
use strict;
use warnings;

{ # BLOCK to scope variables

sub get_xmlns { 'http://www.onvif.org/ver10/media/wsdl' }

__PACKAGE__->__set_name('GetVideoEncoderConfigurationOptionsResponse');
__PACKAGE__->__set_nillable();
__PACKAGE__->__set_minOccurs();
__PACKAGE__->__set_maxOccurs();
__PACKAGE__->__set_ref();

use base qw(
    SOAP::WSDL::XSD::Typelib::Element
    SOAP::WSDL::XSD::Typelib::ComplexType
);

our $XML_ATTRIBUTE_CLASS;
undef $XML_ATTRIBUTE_CLASS;

sub __get_attr_class {
    return $XML_ATTRIBUTE_CLASS;
}

use Class::Std::Fast::Storable constructor => 'none';
use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

Class::Std::initialize();

{ # BLOCK to scope variables

my %Options_of :ATTR(:get<Options>);

__PACKAGE__->_factory(
    [ qw(        Options

    ) ],
    {
        'Options' => \%Options_of,
    },
    {
        'Options' => 'ONVIF::Media::Types::VideoEncoderConfigurationOptions',
    },
    {

        'Options' => 'Options',
    }
);

} # end BLOCK







} # end of BLOCK



1;


=pod

=head1 NAME

ONVIF::Media::Elements::GetVideoEncoderConfigurationOptionsResponse

=head1 DESCRIPTION

Perl data type class for the XML Schema defined element
GetVideoEncoderConfigurationOptionsResponse from the namespace http://www.onvif.org/ver10/media/wsdl.







=head1 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

=over

=item * Options

 $element->set_Options($data);
 $element->get_Options();





=back


=head1 METHODS

=head2 new

 my $element = ONVIF::Media::Elements::GetVideoEncoderConfigurationOptionsResponse->new($data);

Constructor. The following data structure may be passed to new():

 {
   Options =>  { # ONVIF::Media::Types::VideoEncoderConfigurationOptions
     QualityRange =>  { # ONVIF::Media::Types::IntRange
       Min =>  $some_value, # int
       Max =>  $some_value, # int
     },
     JPEG =>  { # ONVIF::Media::Types::JpegOptions
       ResolutionsAvailable =>  { # ONVIF::Media::Types::VideoResolution
         Width =>  $some_value, # int
         Height =>  $some_value, # int
       },
       FrameRateRange =>  { # ONVIF::Media::Types::IntRange
         Min =>  $some_value, # int
         Max =>  $some_value, # int
       },
       EncodingIntervalRange =>  { # ONVIF::Media::Types::IntRange
         Min =>  $some_value, # int
         Max =>  $some_value, # int
       },
     },
     MPEG4 =>  { # ONVIF::Media::Types::Mpeg4Options
       ResolutionsAvailable =>  { # ONVIF::Media::Types::VideoResolution
         Width =>  $some_value, # int
         Height =>  $some_value, # int
       },
       GovLengthRange =>  { # ONVIF::Media::Types::IntRange
         Min =>  $some_value, # int
         Max =>  $some_value, # int
       },
       FrameRateRange =>  { # ONVIF::Media::Types::IntRange
         Min =>  $some_value, # int
         Max =>  $some_value, # int
       },
       EncodingIntervalRange =>  { # ONVIF::Media::Types::IntRange
         Min =>  $some_value, # int
         Max =>  $some_value, # int
       },
       Mpeg4ProfilesSupported => $some_value, # Mpeg4Profile
     },
     H264 =>  { # ONVIF::Media::Types::H264Options
       ResolutionsAvailable =>  { # ONVIF::Media::Types::VideoResolution
         Width =>  $some_value, # int
         Height =>  $some_value, # int
       },
       GovLengthRange =>  { # ONVIF::Media::Types::IntRange
         Min =>  $some_value, # int
         Max =>  $some_value, # int
       },
       FrameRateRange =>  { # ONVIF::Media::Types::IntRange
         Min =>  $some_value, # int
         Max =>  $some_value, # int
       },
       EncodingIntervalRange =>  { # ONVIF::Media::Types::IntRange
         Min =>  $some_value, # int
         Max =>  $some_value, # int
       },
       H264ProfilesSupported => $some_value, # H264Profile
     },
     Extension =>  { # ONVIF::Media::Types::VideoEncoderOptionsExtension
       JPEG =>  { # ONVIF::Media::Types::JpegOptions2
         BitrateRange =>  { # ONVIF::Media::Types::IntRange
           Min =>  $some_value, # int
           Max =>  $some_value, # int
         },
       },
       MPEG4 =>  { # ONVIF::Media::Types::Mpeg4Options2
         BitrateRange =>  { # ONVIF::Media::Types::IntRange
           Min =>  $some_value, # int
           Max =>  $some_value, # int
         },
       },
       H264 =>  { # ONVIF::Media::Types::H264Options2
         BitrateRange =>  { # ONVIF::Media::Types::IntRange
           Min =>  $some_value, # int
           Max =>  $some_value, # int
         },
       },
       Extension =>  { # ONVIF::Media::Types::VideoEncoderOptionsExtension2
       },
     },
   },
 },

=head1 AUTHOR

Generated by SOAP::WSDL

=cut

