
package ONVIF::PTZ::Attributes::expectedContentTypes;
use strict;
use warnings;

{ # BLOCK to scope variables

sub get_xmlns { 'http://www.w3.org/2005/05/xmlmime' }

__PACKAGE__->__set_name('expectedContentTypes');
__PACKAGE__->__set_ref();
use base qw(
    SOAP::WSDL::XSD::Typelib::Attribute
    SOAP::WSDL::XSD::Typelib::Builtin::string
);

}

1;


=pod

=head1 NAME

ONVIF::PTZ::Attributes::expectedContentTypes

=head1 DESCRIPTION

Perl data type class for the XML Schema defined attribute
expectedContentTypes from the namespace http://www.w3.org/2005/05/xmlmime.







=head1 METHODS

=head2 new

 my $element = ONVIF::PTZ::Attributes::expectedContentTypes->new($data);

Constructor. The following data structure may be passed to new():

 { value => $value }

=head1 AUTHOR

Generated by SOAP::WSDL

=cut

