
package WSNotification::Elements::GetCurrentMessage;
use strict;
use warnings;

{ # BLOCK to scope variables

sub get_xmlns { 'http://docs.oasis-open.org/wsn/b-2' }

__PACKAGE__->__set_name('GetCurrentMessage');
__PACKAGE__->__set_nillable();
__PACKAGE__->__set_minOccurs();
__PACKAGE__->__set_maxOccurs();
__PACKAGE__->__set_ref();

use base qw(
    SOAP::WSDL::XSD::Typelib::Element
    SOAP::WSDL::XSD::Typelib::ComplexType
);

our $XML_ATTRIBUTE_CLASS;
undef $XML_ATTRIBUTE_CLASS;

sub __get_attr_class {
    return $XML_ATTRIBUTE_CLASS;
}

use Class::Std::Fast::Storable constructor => 'none';
use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

Class::Std::initialize();

{ # BLOCK to scope variables

my %Topic_of :ATTR(:get<Topic>);

__PACKAGE__->_factory(
    [ qw(        Topic

    ) ],
    {
        'Topic' => \%Topic_of,
    },
    {
        'Topic' => 'WSNotification::Types::TopicExpressionType',
    },
    {

        'Topic' => 'Topic',
    }
);

} # end BLOCK







} # end of BLOCK



1;


=pod

=head1 NAME

WSNotification::Elements::GetCurrentMessage

=head1 DESCRIPTION

Perl data type class for the XML Schema defined element
GetCurrentMessage from the namespace http://docs.oasis-open.org/wsn/b-2.







=head1 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

=over

=item * Topic

 $element->set_Topic($data);
 $element->get_Topic();





=back


=head1 METHODS

=head2 new

 my $element = WSNotification::Elements::GetCurrentMessage->new($data);

Constructor. The following data structure may be passed to new():

 {
   Topic =>  { # WSNotification::Types::TopicExpressionType
   },
 },

=head1 AUTHOR

Generated by SOAP::WSDL

=cut

