
package WSDiscovery10::Elements::ResolveMatches;
use strict;
use warnings;

{ # BLOCK to scope variables

sub get_xmlns { 'http://schemas.xmlsoap.org/ws/2005/04/discovery' }

__PACKAGE__->__set_name('ResolveMatches');
__PACKAGE__->__set_nillable();
__PACKAGE__->__set_minOccurs();
__PACKAGE__->__set_maxOccurs();
__PACKAGE__->__set_ref();
use base qw(
    SOAP::WSDL::XSD::Typelib::Element
    WSDiscovery10::Types::ResolveMatchesType
);

}

1;


=pod

=head1 NAME

WSDiscovery10::Elements::ResolveMatches

=head1 DESCRIPTION

Perl data type class for the XML Schema defined element
ResolveMatches from the namespace http://schemas.xmlsoap.org/ws/2005/04/discovery.







=head1 METHODS

=head2 new

 my $element = WSDiscovery10::Elements::ResolveMatches->new($data);

Constructor. The following data structure may be passed to new():

 { # WSDiscovery10::Types::ResolveMatchesType
   ResolveMatch =>  { # WSDiscovery10::Types::ResolveMatchType
     EndpointReference =>  { # WSDiscovery10::Types::EndpointReferenceType
       Address =>  { value => $some_value },
       ReferenceProperties =>  { # WSDiscovery10::Types::ReferencePropertiesType
       },
       ReferenceParameters =>  { # WSDiscovery10::Types::ReferenceParametersType
       },
       PortType =>  { value => $some_value },
       ServiceName =>  { value => $some_value },
     },
     Types => $some_value, # QNameListType
     Scopes =>  { value => $some_value },
     XAddrs => $some_value, # UriListType
     MetadataVersion =>  $some_value, # unsignedInt
   },
 },

=head1 AUTHOR

Generated by SOAP::WSDL

=cut

