.spinner {
	position: absolute;
	opacity: 0.9;
	filter: alpha(opacity=90);
	-ms-filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=90);
	z-index: 1001;
	background: #fff;
}
.spinner-msg {
	text-align: center;
	font-weight: bold;
}

.spinner-img {
	background: url(/graphics/spinner.gif) no-repeat;
	width: 24px;
	height: 24px;
	margin: 0 auto;
}
