package WSDiscovery10::Types::SigType;
use strict;
use warnings;


__PACKAGE__->_set_element_form_qualified(0);

sub get_xmlns { 'http://schemas.xmlsoap.org/ws/2005/04/discovery' };

our $XML_ATTRIBUTE_CLASS = 'WSDiscovery10::Types::SigType::_SigType::XmlAttr';

sub __get_attr_class {
    return $XML_ATTRIBUTE_CLASS;
}

use Class::Std::Fast::Storable constructor => 'none';
use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

Class::Std::initialize();

{ # BLOCK to scope variables


__PACKAGE__->_factory(
    [ qw(
    ) ],
    {
    },
    {
    },
    {

    }
);

} # end BLOCK




package WSDiscovery10::Types::SigType::_SigType::XmlAttr;
use base qw(SOAP::WSDL::XSD::Typelib::AttributeSet);

{ # BLOCK to scope variables

my %Scheme_of :ATTR(:get<Scheme>);
my %KeyId_of :ATTR(:get<KeyId>);
my %Refs_of :ATTR(:get<Refs>);
my %Sig_of :ATTR(:get<Sig>);

__PACKAGE__->_factory(
    [ qw(
        Scheme
        KeyId
        Refs
        Sig
    ) ],
    {

        Scheme => \%Scheme_of,

        KeyId => \%KeyId_of,

        Refs => \%Refs_of,

        Sig => \%Sig_of,
    },
    {
        Scheme => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
        KeyId => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
        Refs => 'SOAP::WSDL::XSD::Typelib::Builtin::IDREFS',
        Sig => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
    }
);

} # end BLOCK




1;


=pod

=head1 NAME

WSDiscovery10::Types::SigType

=head1 DESCRIPTION

Perl data type class for the XML Schema defined complexType
SigType from the namespace http://schemas.xmlsoap.org/ws/2005/04/discovery.






=head2 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

=over



=back


=head1 METHODS

=head2 new

Constructor. The following data structure may be passed to new():

 { # WSDiscovery10::Types::SigType
 },



=head2 attr

NOTE: Attribute documentation is experimental, and may be inaccurate.
See the correspondent WSDL/XML Schema if in question.

This class has additional attributes, accessibly via the C<attr()> method.

attr() returns an object of the class WSDiscovery10::Types::SigType::_SigType::XmlAttr.

The following attributes can be accessed on this object via the corresponding
get_/set_ methods:

=over

=item * Scheme



This attribute is of type L<SOAP::WSDL::XSD::Typelib::Builtin::anyURI|SOAP::WSDL::XSD::Typelib::Builtin::anyURI>.

=item * KeyId



This attribute is of type L<SOAP::WSDL::XSD::Typelib::Builtin::base64Binary|SOAP::WSDL::XSD::Typelib::Builtin::base64Binary>.

=item * Refs



This attribute is of type L<SOAP::WSDL::XSD::Typelib::Builtin::IDREFS|SOAP::WSDL::XSD::Typelib::Builtin::IDREFS>.

=item * Sig



This attribute is of type L<SOAP::WSDL::XSD::Typelib::Builtin::base64Binary|SOAP::WSDL::XSD::Typelib::Builtin::base64Binary>.


=back




=head1 AUTHOR

Generated by SOAP::WSDL

=cut

