
package ONVIF::Analytics::Elements::VideoAnalyticsConfiguration;
use strict;
use warnings;

{ # BLOCK to scope variables

sub get_xmlns { 'http://www.onvif.org/ver10/schema' }

__PACKAGE__->__set_name('VideoAnalyticsConfiguration');
__PACKAGE__->__set_nillable();
__PACKAGE__->__set_minOccurs();
__PACKAGE__->__set_maxOccurs();
__PACKAGE__->__set_ref();
use base qw(
    SOAP::WSDL::XSD::Typelib::Element
    ONVIF::Analytics::Types::VideoAnalyticsConfiguration
);

}

1;


=pod

=head1 NAME

ONVIF::Analytics::Elements::VideoAnalyticsConfiguration

=head1 DESCRIPTION

Perl data type class for the XML Schema defined element
VideoAnalyticsConfiguration from the namespace http://www.onvif.org/ver10/schema.







=head1 METHODS

=head2 new

 my $element = ONVIF::Analytics::Elements::VideoAnalyticsConfiguration->new($data);

Constructor. The following data structure may be passed to new():

 { # ONVIF::Analytics::Types::VideoAnalyticsConfiguration
   AnalyticsEngineConfiguration =>  { # ONVIF::Analytics::Types::AnalyticsEngineConfiguration
     AnalyticsModule =>  { # ONVIF::Analytics::Types::Config
       Parameters =>  { # ONVIF::Analytics::Types::ItemList
         SimpleItem => ,
         ElementItem =>  {
         },
         Extension =>  { # ONVIF::Analytics::Types::ItemListExtension
         },
       },
     },
     Extension =>  { # ONVIF::Analytics::Types::AnalyticsEngineConfigurationExtension
     },
   },
   RuleEngineConfiguration =>  { # ONVIF::Analytics::Types::RuleEngineConfiguration
     Rule =>  { # ONVIF::Analytics::Types::Config
       Parameters =>  { # ONVIF::Analytics::Types::ItemList
         SimpleItem => ,
         ElementItem =>  {
         },
         Extension =>  { # ONVIF::Analytics::Types::ItemListExtension
         },
       },
     },
     Extension =>  { # ONVIF::Analytics::Types::RuleEngineConfigurationExtension
     },
   },
 },

=head1 AUTHOR

Generated by SOAP::WSDL

=cut

