.chartSize {
    width: <?php echo $chart['width'] ?>px;
    height: <?php echo $chart['height'] ?>px;
}

.graphSize {
    width: <?php echo $chart['graph']['width'] ?>px;
    height: <?php echo $chart['graph']['height'] ?>px;
}

.graphHeight {
    height: <?php echo $chart['graph']['height'] ?>px;
}

.graphWidth {
    width: <?php echo $chart['graph']['width'] ?>px;
}

.imageSize {
    width: <?php echo $chart['image']['width'] ?>px;
    height: <?php echo $chart['image']['height'] ?>px;
}

.imageHeight {
    height: <?php echo $chart['image']['height'] ?>px;
}

.activitySize {
    width: <?php echo $chart['graph']['width'] ?>px;
    height: <?php echo $chart['graph']['activityHeight'] ?>px;
}

.eventsSize {
    width: <?php echo $chart['graph']['width'] ?>px;
    height: <?php echo $chart['graph']['eventBarHeight'] ?>px;
}

.events .event {
    height: <?php echo $chart['graph']['eventBarHeight'] ?>px;
}
?>
