
package WSNotification::Attributes::topic;
use strict;
use warnings;

{ # BLOCK to scope variables

sub get_xmlns { 'http://docs.oasis-open.org/wsn/t-1' }

__PACKAGE__->__set_name('topic');
__PACKAGE__->__set_ref();
use base qw(
    SOAP::WSDL::XSD::Typelib::Attribute
    SOAP::WSDL::XSD::Typelib::Builtin::boolean
);

}

1;


=pod

=head1 NAME

WSNotification::Attributes::topic

=head1 DESCRIPTION

Perl data type class for the XML Schema defined attribute
topic from the namespace http://docs.oasis-open.org/wsn/t-1.







=head1 METHODS

=head2 new

 my $element = WSNotification::Attributes::topic->new($data);

Constructor. The following data structure may be passed to new():

 { value => $value }

=head1 AUTHOR

Generated by SOAP::WSDL

=cut

