package ONVIF::Media::Types::VideoAnalyticsStream;
use strict;
use warnings;


__PACKAGE__->_set_element_form_qualified(1);

sub get_xmlns { 'http://www.onvif.org/ver10/schema' };

our $XML_ATTRIBUTE_CLASS;
undef $XML_ATTRIBUTE_CLASS;

sub __get_attr_class {
    return $XML_ATTRIBUTE_CLASS;
}

use Class::Std::Fast::Storable constructor => 'none';
use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

Class::Std::initialize();

{ # BLOCK to scope variables

my %Frame_of :ATTR(:get<Frame>);
my %Extension_of :ATTR(:get<Extension>);

__PACKAGE__->_factory(
    [ qw(        Frame
        Extension

    ) ],
    {
        'Frame' => \%Frame_of,
        'Extension' => \%Extension_of,
    },
    {
        'Frame' => 'ONVIF::Media::Types::Frame',
        'Extension' => 'ONVIF::Media::Types::VideoAnalyticsStreamExtension',
    },
    {

        'Frame' => 'Frame',
        'Extension' => 'Extension',
    }
);

} # end BLOCK








1;


=pod

=head1 NAME

ONVIF::Media::Types::VideoAnalyticsStream

=head1 DESCRIPTION

Perl data type class for the XML Schema defined complexType
VideoAnalyticsStream from the namespace http://www.onvif.org/ver10/schema.






=head2 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

=over

=item * Frame


=item * Extension




=back


=head1 METHODS

=head2 new

Constructor. The following data structure may be passed to new():

 { # ONVIF::Media::Types::VideoAnalyticsStream
   # One of the following elements.
   # No occurrence checks yet, so be sure to pass just one...
   Frame =>  { # ONVIF::Media::Types::Frame
     PTZStatus =>  { # ONVIF::Media::Types::PTZStatus
       Position =>  { # ONVIF::Media::Types::PTZVector
         PanTilt => ,
         Zoom => ,
       },
       MoveStatus =>  { # ONVIF::Media::Types::PTZMoveStatus
         PanTilt => $some_value, # MoveStatus
         Zoom => $some_value, # MoveStatus
       },
       Error =>  $some_value, # string
       UtcTime =>  $some_value, # dateTime
     },
     Transformation =>  { # ONVIF::Media::Types::Transformation
       Translate => ,
       Scale => ,
       Extension =>  { # ONVIF::Media::Types::TransformationExtension
       },
     },
     Object =>  { # ONVIF::Media::Types::Object
       Appearance =>  { # ONVIF::Media::Types::Appearance
         Transformation =>  { # ONVIF::Media::Types::Transformation
           Translate => ,
           Scale => ,
           Extension =>  { # ONVIF::Media::Types::TransformationExtension
           },
         },
         Shape =>  { # ONVIF::Media::Types::ShapeDescriptor
           BoundingBox => ,
           CenterOfGravity => ,
           Polygon =>  { # ONVIF::Media::Types::Polygon
             Point => ,
           },
           Extension =>  { # ONVIF::Media::Types::ShapeDescriptorExtension
           },
         },
         Color =>  { # ONVIF::Media::Types::ColorDescriptor
           ColorCluster =>  {
             Color => ,
             Weight =>  $some_value, # float
             Covariance => ,
           },
           Extension =>  { # ONVIF::Media::Types::ColorDescriptorExtension
           },
         },
         Class =>  { # ONVIF::Media::Types::ClassDescriptor
           ClassCandidate =>  {
             Type => $some_value, # ClassType
             Likelihood =>  $some_value, # float
           },
           Extension =>  { # ONVIF::Media::Types::ClassDescriptorExtension
             OtherTypes =>  { # ONVIF::Media::Types::OtherType
               Type =>  $some_value, # string
               Likelihood =>  $some_value, # float
             },
             Extension =>  { # ONVIF::Media::Types::ClassDescriptorExtension2
             },
           },
         },
         Extension =>  { # ONVIF::Media::Types::AppearanceExtension
         },
       },
       Behaviour =>  { # ONVIF::Media::Types::Behaviour
         Removed =>  {
         },
         Idle =>  {
         },
         Extension =>  { # ONVIF::Media::Types::BehaviourExtension
         },
       },
       Extension =>  { # ONVIF::Media::Types::ObjectExtension
       },
     },
     ObjectTree =>  { # ONVIF::Media::Types::ObjectTree
       Rename =>  { # ONVIF::Media::Types::Rename
         from => ,
         to => ,
       },
       Split =>  { # ONVIF::Media::Types::Split
         from => ,
         to => ,
       },
       Merge =>  { # ONVIF::Media::Types::Merge
         from => ,
         to => ,
       },
       Delete => ,
       Extension =>  { # ONVIF::Media::Types::ObjectTreeExtension
       },
     },
     Extension =>  { # ONVIF::Media::Types::FrameExtension
       MotionInCells =>  { # ONVIF::Media::Types::MotionInCells
       },
       Extension =>  { # ONVIF::Media::Types::FrameExtension2
       },
     },
   },
   Extension =>  { # ONVIF::Media::Types::VideoAnalyticsStreamExtension
   },
 },




=head1 AUTHOR

Generated by SOAP::WSDL

=cut

